from flask import Flask
from actelink.config import settings
from actelink.logger import log
from actelink.api import api

def create_app():
  log.info(f'{__name__}')
  app = Flask(__name__)
  app.config.from_prefixed_env()
  app.config['SECRET_KEY'] = settings.SECRET_KEY
  api.init_app(app)

  return app


from os import environ
from dotenv import load_dotenv
from .settings import Settings
from actelink.logger import log

# load .env files if any, no override on existing system env variables
load_dotenv()
settings = Settings()

# environment can override default settings
for atr in [f for f in dir(settings) if not '__' in f]:
  val = environ.get(atr, getattr(settings, atr))
  setattr(settings, atr, val)
  log.debug(f"{atr}={getattr(settings, atr)}")



from . import Context, Calcul, Regime, NiveauProduit
from typing import List, Optional
from pydantic import BaseModel

class ContextSchema(BaseModel):
    context: Context

class ContextsSchema(BaseModel):
    contexts = List[ContextSchema]

class ComputationContexts(BaseModel):
    contexts: ContextSchema
    offre = fields.String()
    guarantyId = fields.String()
    calcul = fields.String()